pub struct RowNumberProvider { /* private fields */ }Expand description
Provides stable row numbers for keys with automatic Insert/Update detection
This component maintains:
- A sequential counter for generating new row numbers
- A mapping from keys to their assigned row numbers
When a key is seen for the first time, it gets a new row number and returns true. When a key is seen again, it returns the existing row number and false.
Implementations
Sourceimpl RowNumberProvider
impl RowNumberProvider
pub fn new(node: FlowNodeId) -> Self
Sourcepub fn get_or_create_row_numbers_batch<'a, I>(
&self,
ctx: &mut OperatorContext,
keys: I,
) -> Result<Vec<(RowNumber, bool)>>where
I: IntoIterator<Item = &'a EncodedKey>,
pub fn get_or_create_row_numbers_batch<'a, I>(
&self,
ctx: &mut OperatorContext,
keys: I,
) -> Result<Vec<(RowNumber, bool)>>where
I: IntoIterator<Item = &'a EncodedKey>,
Get or create RowNumbers for a batch of keys Returns Vec<(RowNumber, is_new)> in the same order as input keys where is_new indicates if the row number was newly created
pub fn get_or_create_row_number( &self, ctx: &mut OperatorContext, key: &EncodedKey, ) -> Result<(RowNumber, bool)>
pub fn remove_by_prefix( &self, ctx: &mut OperatorContext, key_prefix: &[u8], ) -> Result<()>